@category = N_("Toolkit")
@title = N_("Tag")
@abstract = N_("Toolkit to apply custom tag")
@description = N_("Applies custom tag style.")
